@@ -49,12 +49,16 @@ RFnames {
 } RFnames;
 /*----------------------------------------------------------------------------*/
 /**
- * @fn      RFnames * rfnames_new (void)
- * @brief   Create new RFnames object.
+ * @fn  RFnames * rfnames_new (void)
+ *
+ * @brief  Create new RFnames object.
+ *
  * @return  New RFnames object
  *
- * @fn            void rfnames_free (RFnames *rf_names)
- * @brief         Free allocated memory.
+ * @fn  void rfnames_free (RFnames *rf_names)
+ *
+ * @brief  Free allocated memory.
+ *
  * @param[in,out] rf_names Pointer to RFnames object
  * @return        none
  */
@@ -74,18 +78,22 @@ GtkWidget * rfnames_append_gfile (RFnames *rf_names,
                                   GFile   *g_file);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn         void rfnames_add_gfile_to_file_box (RFnames *rf_names,
- *                                                 GFile   *g_file)
- * @brief      Create new RFitem object using data from gfile item and add it
- *             to RFnames item.
+ * @fn  void rfnames_add_gfile_to_file_box (RFnames *rf_names,
+ *                                          GFile   *g_file)
+ *
+ * @brief  Create new RFitem object using data from gfile item and add it
+ *         to RFnames item.
+ *
  * @param[out] rf_names Pointer to RFnames object
  * @param[in]  g_file   GFile object
  * @return     none
  *
- * @fn         void rfnames_add_sfile_to_file_box (RFnames    *rf_names,
- *                                                 const char *s_fn)
- * @brief      Create new RFitem object using data from s_fn string and add it
- *             to RFnames item.
+ * @fn  void rfnames_add_sfile_to_file_box (RFnames    *rf_names,
+ *                                          const char *s_fn)
+ *
+ * @brief  Create new RFitem object using data from s_fn string and add it
+ *         to RFnames item.
+ *
  * @param[out] rf_names Pointer to RFnames object
  * @param[in]  s_fn     String with file path
  * @return     none
@@ -103,80 +111,107 @@ void rfnames_add_sfile_to_file_box (RFnames    *rf_names,
  * @param[in] rf_names Pointer to RFnames object
  * @return    Length of list
  */
-uint_fast32_t rfnames_get_cnt (const RFnames *rf_names)
-              __attribute__ ((pure));
+uint_fast32_t rfnames_get_cnt (const RFnames *rf_names) __attribute__ ((pure));
 /*----------------------------------------------------------------------------*/
 /**
- * @fn         void rfnames_select_unselect_all (RFnames *rf_names)
- * @brief      Select or unselect all check items on list.
+ * @fn  void rfnames_select_unselect_all (RFnames *rf_names)
+ *
+ * @brief  Select or unselect all check items on list.
+ *
  * @param[out] rf_names RFnames list
  * @return     none
  *
- * @fn         void rfnames_select_files (RFnames *rf_names)
- * @brief      Select all items with file type on list.
- * @param[out] rf_names RFnames list
- * @return     none
+ * @fn  void rfnames_select_invert (RFnames *rf_names)
  *
- * @fn         void rfnames_unselect_files (RFnames *rf_names)
- * @brief      Unselect all items with file type on list.
- * @param[out] rf_names RFnames list
- * @return     none
+ * @brief  Invert selection of items on list.
  *
- * @fn         void rfnames_select_folders (RFnames *rf_names)
- * @brief      Select all items with folder type on list.
- * @param[out] rf_names RFnames list
- * @return     none
- *
- * @fn         void rfnames_unselect_folders (RFnames *rf_names)
- * @brief      Unselect all items with folder type on list.
- * @param[out] rf_names RFnames list
- * @return     none
- *
- * @fn         void rfnames_select_symlinks (RFnames *rf_names)
- * @brief      Select all items with symlink type on list.
- * @param[out] rf_names RFnames list
- * @return     none
- *
- * @fn         void rfnames_unselect_symlinks (RFnames *rf_names)
- * @brief      Unselect all items with symlink type on list.
- * @param[out] rf_names RFnames list
- * @return     none
- *
- * @fn         void rfnames_select_hidden (RFnames *rf_names)
- * @brief      Select all items with hidden type on list.
- * @param[out] rf_names RFnames list
- * @return     none
- *
- * @fn         void rfnames_unselect_hidden (RFnames *rf_names)
- * @brief      Unselect all items with hidden type on list.
- * @param[out] rf_names RFnames list
- * @return     none
- *
- * @fn         void rfnames_select_invert (RFnames *rf_names)
- * @brief      Invert selection of items on list.
  * @param[out] rf_names RFnames list
  * @return     none
  */
 /*----------------------------------------------------------------------------*/
 void rfnames_select_unselect_all (RFnames *rf_names);
 
+void rfnames_select_invert       (RFnames *rf_names);
+/*----------------------------------------------------------------------------*/
+/**
+ * @fn  void rfnames_select_files (RFnames *rf_names)
+ *
+ * @brief  Select all items with file type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ *
+ * @fn  void rfnames_unselect_files (RFnames *rf_names)
+ *
+ * @brief  Unselect all items with file type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ */
+/*----------------------------------------------------------------------------*/
 void rfnames_select_files        (RFnames *rf_names);
 
 void rfnames_unselect_files      (RFnames *rf_names);
-
+/*----------------------------------------------------------------------------*/
+/**
+ * @fn  void rfnames_select_folders (RFnames *rf_names)
+ *
+ * @brief  Select all items with folder type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ *
+ * @fn  void rfnames_unselect_folders (RFnames *rf_names)
+ *
+ * @brief  Unselect all items with folder type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ */
+/*----------------------------------------------------------------------------*/
 void rfnames_select_folders      (RFnames *rf_names);
 
 void rfnames_unselect_folders    (RFnames *rf_names);
-
+/*----------------------------------------------------------------------------*/
+/**
+ * @fn  void rfnames_select_symlinks (RFnames *rf_names)
+ *
+ * @brief  Select all items with symlink type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ *
+ * @fn  void rfnames_unselect_symlinks (RFnames *rf_names)
+ *
+ * @brief  Unselect all items with symlink type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ */
+/*----------------------------------------------------------------------------*/
 void rfnames_select_symlinks     (RFnames *rf_names);
 
 void rfnames_unselect_symlinks   (RFnames *rf_names);
-
+/*----------------------------------------------------------------------------*/
+/**
+ * @fn  void rfnames_select_hidden (RFnames *rf_names)
+ *
+ * @brief  Select all items with hidden type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ *
+ * @fn  void rfnames_unselect_hidden (RFnames *rf_names)
+ *
+ * @brief  Unselect all items with hidden type on list.
+ *
+ * @param[out] rf_names RFnames list
+ * @return     none
+ */
+/*----------------------------------------------------------------------------*/
 void rfnames_select_hidden       (RFnames *rf_names);
 
 void rfnames_unselect_hidden     (RFnames *rf_names);
-
-void rfnames_select_invert       (RFnames *rf_names);
 /*----------------------------------------------------------------------------*/
 /**
  * @fn            void rfnames_remove_selected (RFnames *rf_names)
@@ -223,13 +258,17 @@ void rfnames_remove_all_symlinks (RFnames *rf_names);
 void rfnames_remove_all_hidden   (RFnames *rf_names);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn            void rfnames_restore_selected (RFnames *rf_names)
- * @brief         Restore original file name in selected RFitem objects on list.
+ * @fn  void rfnames_restore_selected (RFnames *rf_names)
+ *
+ * @brief  Restore original file name in selected RFitem objects on list.
+ *
  * @param[in,out] rf_names RFnames list to restore original names
  * @return        none
  *
- * @fn            void rfnames_restore_all (RFnames *rf_names)
- * @brief         Restore original file name in all RFitem objects on list.
+ * @fn  void rfnames_restore_all (RFnames *rf_names)
+ *
+ * @brief  Restore original file name in all RFitem objects on list.
+ *
  * @param[in,out] rf_names RFnames list to restore original names
  * @return        none
  */
