@@ -21,9 +21,9 @@
  *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gmodule.h>
 #include <err.h>
 #include "strfn.h"
 #include "rreplace.h"
@@ -39,6 +39,10 @@ rreplace_init (RReplace *r_replace)
 {
     memset (r_replace->s_from, '\0', sizeof (r_replace->s_from));
     memset (r_replace->s_to,   '\0', sizeof (r_replace->s_to));
+    r_replace->from_len   = 0;
+    r_replace->from_u8len = 0;
+    r_replace->to_len     = 0;
+    r_replace->to_u8len   = 0;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -65,12 +69,18 @@ rreplace_free (RReplace *r_replace)
     free (r_replace);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get "from" string.
+ */
 const char *
 rreplace_get_from (const RReplace *r_replace)
 {
     return (const char *) r_replace->s_from;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set "from" string.
+ */
 void
 rreplace_set_from (RReplace   *r_replace,
                    const char *val)
@@ -79,14 +89,22 @@ rreplace_set_from (RReplace   *r_replace,
 
     memcpy (r_replace->s_from, val, ui_len);
     r_replace->s_from[ui_len] = '\0';
+    r_replace->from_len   = ui_len;
+    r_replace->from_u8len = (size_t) g_utf8_strlen (val, -1);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get "to" string.
+ */
 const char *
 rreplace_get_to (const RReplace *r_replace)
 {
     return (const char *) r_replace->s_to;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set "to" string.
+ */
 void
 rreplace_set_to (RReplace   *r_replace,
                  const char *val)
@@ -95,14 +113,58 @@ rreplace_set_to (RReplace   *r_replace,
 
     memcpy (r_replace->s_to, val, ui_len);
     r_replace->s_to[ui_len] = '\0';
+    r_replace->to_len   = ui_len;
+    r_replace->to_u8len = (size_t) g_utf8_strlen (val, -1);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get s_from string length value.
+ */
+size_t
+rreplace_get_from_len (const RReplace *r_replace)
+{
+    return r_replace->from_len;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get s_from string unicode length value.
+ */
+size_t
+rreplace_get_from_u8len (const RReplace *r_replace)
+{
+    return r_replace->from_u8len;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get s_to string length value.
+ */
+size_t
+rreplace_get_to_len (const RReplace *r_replace)
+{
+    return r_replace->to_len;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get s_to string unicode length value.
+ */
+size_t
+rreplace_get_to_u8len (const RReplace *r_replace)
+{
+    return r_replace->to_u8len;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Check if "from" string is an empty string.
+ */
 int
 rreplace_empty_from (const RReplace *r_replace)
 {
     return (r_replace->s_from[0] == '\0');
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Check if "to" string is an empty string.
+ */
 int
 rreplace_empty_to (const RReplace *r_replace)
 {
